from Converter import Converter
from Components.Sources.Clock import Clock
from time import time as getTime, localtime, strftime
from Poll import Poll
from Components.Element import cached
import os.path

hours24 = False
filename = '/usr/share/enigma2/timeformat.txt'


if os.path.exists(filename):
	with open(filename, "r") as myfile:
		if 'Time = 24' in myfile.read():
			hours24 = True
		else:
			hours24 = False


		
class UkClockToText(Converter, object):
    DEFAULT = 0
    FORMAT = 1
    SKY_AS_LENGTH = 2
    SKY_Q_DATE = 3
    SKY_HD_DATE = 4
    SKY_HD_TIME = 5
    SKY_STARTTIME = 6
    NORMAL = 7

    def __init__(self, type):
        Converter.__init__(self, type)

        self.fix = ""
        if ';' in type:
            type, self.fix = type.split(';')

        if type == "SkyAsLength":
            self.type = self.SKY_AS_LENGTH
        elif type == "SkyQDate":
            self.type = self.SKY_Q_DATE
        elif type == "SkyHDDate":
            self.type = self.SKY_HD_DATE
        elif type == "SkyHDTime":
            self.type = self.SKY_HD_TIME
        elif type == "SkyStartAt":
            self.type = self.SKY_STARTTIME
        elif type == "Normal":
            self.type = self.NORMAL
        elif "Format" in type:
            self.type = self.FORMAT
            self.fmt_string = type[7:]
        else:
            self.type = self.DEFAULT

    @cached
    def getText(self):
        time = self.source.time
        t = localtime(time)
        tnow = getTime()

        if time is None:
            return ""

        def fix_space(string):
            if "Proportional" in self.fix and t.tm_hour < 10:
                return " " + string
            if "NoSpace" in self.fix:
                return string.lstrip()
            return string

        if self.type == self.SKY_AS_LENGTH:
            # below is 9 to not show duration on directories for movies
            if time <= 9:
                return ""
            else:
                if time / 3600 < 1:
                    return ngettext("%d Min", "%d Mins", (time / 60)) % (time / 60)
                elif time / 60 % 60 == 0:
                    return ngettext("%d Hour", "%d Hours", (time / 3600)) % (time / 3600)
                else:
                    return "%dh %2dm" % (time / 3600, time / 60 % 60)

        if int(strftime("%H", t)) >= 12:
            timesuffix = _('pm')
        else:
            timesuffix = _('am')
			
		

        if self.type == self.DEFAULT:
            return fix_space(_("%2d:%02d") % (t.tm_hour, t.tm_min))
        
        elif self.type == self.SKY_Q_DATE:
			if hours24:
				d = _("%A, %H.%M")
			else:
				d = _("%A, %l.%M") + _(timesuffix)

        elif self.type == self.SKY_HD_DATE:
			if hours24:
				d = _("%H.%M") + _(" %a %d/%m")
			else:
				d = _("%l.%M") + _(timesuffix) + _(" %a %d/%m")

			
        elif self.type == self.SKY_HD_TIME:
			if hours24:
				d = _("%H.%M")
			else:
				d = _("%l.%M") + _(timesuffix)
          
           
        elif self.type == self.SKY_STARTTIME:
			if hours24:   
				if time < tnow:
					d = _('Started at ') + _("%H.%M").lstrip()
				else:
					d = _('Starts at ') + _("%H.%M").lstrip() 
			else:
				if time < tnow:
					d = _('Started at ') + _("%l.%M").lstrip() + _(timesuffix)
				else:
					d = _('Starts at ') + _("%l.%M").lstrip() + _(timesuffix)
				
        
        elif self.type == self.NORMAL:
            d = _("%a %e/%m  %-H:%M")
        
        elif self.type == self.FORMAT:
            d = self.fmt_string
        
        else:
            return "???"

        timetext = strftime(d, t)

        return timetext.lstrip(' ')

    text = property(getText)
